@@ -8,6 +8,7 @@ from sdccli.falco_macro import SortMacrosByDepedency
 
 ORIGIN_SECURE_UI = "Secure UI"
 
+
 def dashboards(file_data, sdmonitor, existing_dashboards, restore_unowned):
     errors = []
     ok, userdata = sdmonitor.get_user_info()
@@ -32,7 +33,6 @@ def dashboards(file_data, sdmonitor, existing_dashboards, restore_unowned):
 
         dashboard['id'] = None
         dashboard['version'] = None
-        dashboard['schema'] = 1
         ok, result = sdmonitor.create_dashboard_with_configuration(dashboard)
         if not ok:
             errors.append("couldn't recreate dashboard " + name + ': ' + result)
@@ -75,43 +75,6 @@ def alerts(file_data, monitor: SdMonitorClient):
     return True, None
 
 
-#
-# def alerts(sdmonitor, filename, existing_alerts, changed_ids=None):
-#     with open(filename) as file:
-#         file_data = json.load(file)
-#         errors = []
-#         total = len(file_data['alerts'])
-#         for i, alert in enumerate(file_data['alerts']):
-#             name = alert['name']
-#             print("[{}/{}] Creating alert {}... ".format(i + 1, total, name.strip()))
-#             if name in existing_alerts:
-#                 if same_dict(alert, existing_alerts[name],
-#                              ['id', 'teamId', 'autoCreated',
-#                               'notificationChannelIds', 'notificationCount', 'invalidMetrics',
-#                               'valid']):
-#                     print("      already exists, skip")
-#                     continue
-#                 else:
-#                     sdmonitor.delete_alert(existing_alerts[name])
-#
-#             # Modify the old Ids with the new ones if they are provided
-#             if changed_ids is not None:
-#                 if "notificationChannelIds" in alert:
-#                     changedListKeys = list(changed_ids.keys())
-#                     for indexOldId, oldId in enumerate(alert["notificationChannelIds"]):
-#                         for id in changedListKeys:
-#                             if int(id) == oldId:
-#                                 alert["notificationChannelIds"][indexOldId] = int(changed_ids[id])
-#
-#             ok, result = sdmonitor.create_alert(alert_obj=alert)
-#             if not ok:
-#                 errors.append("couldn't recreate alert " + name + ': ' + result)
-#
-#         if len(errors) != 0:
-#             return False, errors
-#         return True, None
-
-
 def users(sdcommon, filename):
     '''
     Restores users without dropping the existing ones
@@ -223,6 +186,7 @@ def get_user_created_lists(secure: SdSecureClient):
 
     return True, user_created_lists
 
+
 # FIXME: Remove this as soon as the PR is merged in the python-sdc-client
 def _add_falco_list(self, name, items, append=False):
     '''**Description**
@@ -242,7 +206,8 @@ def _add_falco_list(self, name, items, append=False):
         },
         "append": append,
     }
-    res = requests.post(self.url + '/api/secure/falco/lists', data=json.dumps(flist), headers=self.hdrs, verify=self.ssl_verify)
+    res = requests.post(self.url + '/api/secure/falco/lists', data=json.dumps(flist), headers=self.hdrs,
+                        verify=self.ssl_verify)
     return self._request_result(res)
 
 
@@ -357,7 +322,8 @@ def falco_macros(file_data, sdsecure: SdSecureClient):
             sdsecure.update_falco_macro(emacro['id'], macro['condition']['condition'])
             continue
 
-        ok, result = _add_falco_macro(sdsecure, name=name, condition=macro["condition"]["condition"], append=macro['append'])
+        ok, result = _add_falco_macro(sdsecure, name=name, condition=macro["condition"]["condition"],
+                                      append=macro['append'])
         if not ok:
             errors.append("couldn't recreate falco macro " + name + ': ' + result)
 
