@@ -1,7 +1,6 @@
 from abc import ABC, abstractmethod
 
 import yaml
-from sdcclient import SdMonitorClient, SdSecureClient
 
 import sdccli.drop as drop
 import sdccli.restore as restore
@@ -45,19 +44,19 @@ class RestoreUseCase(ABC):
 
 
 class RestoreMonitorUseCase(RestoreUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         self._monitor = monitor
         super().__init__(repository, formatter)
 
 
 class RestoreSecureUseCase(RestoreUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         self._secure = secure
         super().__init__(repository, formatter)
 
 
 class RestoreUsersUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -86,7 +85,7 @@ class RestoreUsersUseCase(RestoreMonitorUseCase):
 
 
 class RestoreNotificationChannelsUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -100,7 +99,7 @@ class RestoreNotificationChannelsUseCase(RestoreMonitorUseCase):
 
 
 class RemoveAndRestoreNotificationChannelsUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -112,7 +111,7 @@ class RemoveAndRestoreNotificationChannelsUseCase(RestoreMonitorUseCase):
 
 
 class RestoreOwnedDashboardsUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -129,7 +128,7 @@ class RestoreOwnedDashboardsUseCase(RestoreMonitorUseCase):
 
 
 class RestoreAllDashboardsUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -146,7 +145,7 @@ class RestoreAllDashboardsUseCase(RestoreMonitorUseCase):
 
 
 class RemoveOwnedAndRestoreOwnedDashboardsUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -158,7 +157,7 @@ class RemoveOwnedAndRestoreOwnedDashboardsUseCase(RestoreMonitorUseCase):
 
 
 class RemoveAllAndRestoreAllDashboardsUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -170,7 +169,7 @@ class RemoveAllAndRestoreAllDashboardsUseCase(RestoreMonitorUseCase):
 
 
 class RestoreAlertsUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -191,7 +190,7 @@ class RestoreAlertsUseCase(RestoreMonitorUseCase):
 
 
 class RemoveAndRestoreAlertsUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -216,7 +215,7 @@ class RemoveAndRestoreAlertsUseCase(RestoreMonitorUseCase):
 
 
 class RestoreTeamsMonitorUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -227,7 +226,7 @@ class RestoreTeamsMonitorUseCase(RestoreMonitorUseCase):
 
 
 class RemoveAndRestoreTeamsMonitorUseCase(RestoreMonitorUseCase):
-    def __init__(self, monitor: SdMonitorClient, repository, formatter=yaml.safe_load):
+    def __init__(self, monitor, repository, formatter=yaml.safe_load):
         super().__init__(monitor, repository, formatter)
 
     def execute(self):
@@ -242,7 +241,7 @@ class RemoveAndRestoreTeamsMonitorUseCase(RestoreMonitorUseCase):
 
 
 class RestoreTeamsSecureUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -253,7 +252,7 @@ class RestoreTeamsSecureUseCase(RestoreSecureUseCase):
 
 
 class RemoveAndRestoreTeamsSecureUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -268,7 +267,7 @@ class RemoveAndRestoreTeamsSecureUseCase(RestoreSecureUseCase):
 
 
 class RestoreFalcoMacrosUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -279,7 +278,7 @@ class RestoreFalcoMacrosUseCase(RestoreSecureUseCase):
 
 
 class RemoveAndRestoreFalcoMacrosUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -293,7 +292,7 @@ class RemoveAndRestoreFalcoMacrosUseCase(RestoreSecureUseCase):
 
 
 class RestoreFalcoListsUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -304,7 +303,7 @@ class RestoreFalcoListsUseCase(RestoreSecureUseCase):
 
 
 class RemoveAndRestoreFalcoListsUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -318,7 +317,7 @@ class RemoveAndRestoreFalcoListsUseCase(RestoreSecureUseCase):
 
 
 class RestoreFalcoRulesUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -329,7 +328,7 @@ class RestoreFalcoRulesUseCase(RestoreSecureUseCase):
 
 
 class RemoveAndRestoreFalcoRulesUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -343,7 +342,7 @@ class RemoveAndRestoreFalcoRulesUseCase(RestoreSecureUseCase):
 
 
 class RestorePoliciesUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -354,7 +353,7 @@ class RestorePoliciesUseCase(RestoreSecureUseCase):
 
 
 class RemoveAndRestorePoliciesUseCase(RestoreSecureUseCase):
-    def __init__(self, secure: SdSecureClient, repository, formatter=yaml.safe_load):
+    def __init__(self, secure, repository, formatter=yaml.safe_load):
         super().__init__(secure, repository, formatter)
 
     def execute(self):
@@ -369,12 +368,12 @@ class RemoveAndRestorePoliciesUseCase(RestoreSecureUseCase):
 
 
 class RemoveSecureUseCase(RemoveUseCase):
-    def __init__(self, secure: SdSecureClient):
+    def __init__(self, secure):
         self._secure = secure
 
 
 class RemovePoliciesUseCase(RemoveSecureUseCase):
-    def __init__(self, secure: SdSecureClient):
+    def __init__(self, secure):
         super().__init__(secure)
 
     def execute(self):
@@ -382,7 +381,7 @@ class RemovePoliciesUseCase(RemoveSecureUseCase):
 
 
 class RemoveFalcoRulesUseCase(RemoveSecureUseCase):
-    def __init__(self, secure: SdSecureClient):
+    def __init__(self, secure):
         super().__init__(secure)
 
     def execute(self):
@@ -390,7 +389,7 @@ class RemoveFalcoRulesUseCase(RemoveSecureUseCase):
 
 
 class RemoveFalcoListsUseCase(RemoveSecureUseCase):
-    def __init__(self, secure: SdSecureClient):
+    def __init__(self, secure):
         super().__init__(secure)
 
     def execute(self):
@@ -398,7 +397,7 @@ class RemoveFalcoListsUseCase(RemoveSecureUseCase):
 
 
 class RemoveFalcoMacrosUseCase(RemoveSecureUseCase):
-    def __init__(self, secure: SdSecureClient):
+    def __init__(self, secure):
         super().__init__(secure)
 
     def execute(self):
